.. venco.py documentation source file, created for sphinx

.. _inputoutput:


Input-Output
===================================

In the venco.py inputs and outputs, we can differentiate between configuration files, disk files and classes outputs.
Moreover, we can distinguish between the overall framework IO and the classes IO.


General Framework Input-Output
---------------------------------------------------
**Inputs:**

 * National travel surveys
 * Mobility patterns from traffic models


**Outputs:**

 * Refer to the outputs of the :ref:`flexestimators` class for more details




Classes Input-Output
---------------------------------------------------

 * :ref:`dataparsers`
 * :ref:`gridmodellers`
 * :ref:`flexestimators`
 * :ref:`diarybuilders`
 * :ref:`profileaggregators`
 * :ref:`postprocessors`
